@@ -209,7 +209,7 @@ def get_mysql_snowflake(usr, pwd, role, warehouse_name, db_name=None, schema=Non
     return engine.connect() #, engine
 
 
-def query_snowflake(query):
+def query_snowflake(query, q_type=None):
     '''
     This funky func is meant to query snowflake and cut out the middle man. Ideally it follows a cred or settings file
     structure. Will open a connection, query snowflake, and close connection and return dataframe
@@ -226,7 +226,11 @@ def query_snowflake(query):
 
     '''
 
-    conn = get_snowflake_connection(**settings.SNOWFLAKE)
+
+    if q_type is not None:
+        conn = get_snowflake_connection(**settings.SNOWFLAKE_FPA)
+    else:
+        conn = get_snowflake_connection(**settings.SNOWFLAKE)
 
     resp =  conn.cursor().execute(query).fetch_pandas_all()
 
